Crate lantun_core

Crate lantun_core 

Structs

ClientTunnel
A ClientTunnel represents the other end of the [HostTunnel].
HostTunnel
A HostTunnel will relay traffic to and from the host_addr to the connected clients (all clients that know this tunnel’s secret).
LanTun
The state of the LanTun application. This tracks both the host and client state, so a user can use other tunnels as well as create their own.

Enums

TunnelProtocol

Constants

ALPN
LANTUN_VERSION

Traits

TunnelCommon

Functions

gen_secret
get_unspecified